@@ -1,4 +1,12 @@
 package MooseX::Getopt::Dashes;
+BEGIN {
+  $MooseX::Getopt::Dashes::AUTHORITY = 'cpan:STEVAN';
+}
+BEGIN {
+  $MooseX::Getopt::Dashes::VERSION = '0.28';
+}
+# ABSTRACT: convert underscores in attribute names to dashes
+
 use Moose::Role;
 
 with 'MooseX::Getopt';
@@ -15,12 +23,16 @@ around _get_cmd_flags_for_attr => sub {
     return ( $flag, @aliases );
 };
 
+no Moose::Role;
+
 1;
 
-__END__
 
+__END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 MooseX::Getopt::Dashes - convert underscores in attribute names to dashes
@@ -59,37 +71,58 @@ a L<cmd_flag|MooseX::Getopt::Meta::Attribute/METHODS> argument with
 the command flag you'd like for a given attribute. No underscore to
 dash replacement will be done on the C<cmd_flag>.
 
-=head1 METHODS
+=head1 AUTHORS
 
 =over 4
 
-=item meta
+=item *
+
+Stevan Little <stevan@iinteractive.com>
+
+=item *
+
+Brandon L. Black <blblack@gmail.com>
+
+=item *
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=item *
+
+Ryan D Johnson <ryan@innerfence.com>
+
+=item *
+
+Drew Taylor <drew@drewtaylor.com>
+
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
+Ævar Arnfjörð Bjarmason <avar@cpan.org>
+
+=item *
+
+Chris Prather <perigrin@cpan.org>
 
 =back
 
-=head1 BUGS
-
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT.
-
-=head1 AUTHOR
-
-Dagfinn Ilmari MannsE<aring>ker E<lt>ilmari@ilmari.orgE<gt>
-
-Stevan Little E<lt>stevan@iinteractive.comE<gt>
-
-Yuval Kogman  C<< <nuffin@cpan.org> >>
-
-E<AElig>var ArnfjE<ouml>rE<eth> Bjarmason E<lt>avar@cpan.orgE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Infinity Interactive, Inc.
+This software is copyright (c) 2010 by Infinity Interactive, Inc.
 
-L<http://www.iinteractive.com>
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
